# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/static_data/v1/set_static_data.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import datetime_pb2 as google_dot_type_dot_datetime__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.services.static_data.v1 import static_data_pb2 as systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_static__data__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?systemathics/apis/services/static_data/v1/set_static_data.proto\x12-systemathics.apis.services.set_static_data.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1agoogle/type/datetime.proto\x1a\x16google/type/date.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a;systemathics/apis/services/static_data/v1/static_data.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\"l\n\x0e\x41ssetIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\x03R\x02id\x12J\n\nasset_type\x18\x02 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\"\xa5\x01\n\x12\x43reateAssetRequest\x12-\n\x08validity\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x08validity\x12W\n\tcds_index\x18\x02 \x01(\x0b\x32\x38.systemathics.apis.services.static_data.v1.CdsIndexEntryH\x00R\x08\x63\x64sIndexB\x07\n\x05\x61sset\"\xa8\x01\n\x05\x41sset\x12\x0e\n\x02id\x18\x01 \x01(\x03R\x02id\x12-\n\x08validity\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x08validity\x12W\n\tcds_index\x18\x03 \x01(\x0b\x32\x38.systemathics.apis.services.static_data.v1.CdsIndexEntryH\x00R\x08\x63\x64sIndexB\x07\n\x05\x61sset2\x99\x06\n\x14SetStaticDataService\x12\xa1\x01\n\x06\x43reate\x12\x41.systemathics.apis.services.set_static_data.v1.CreateAssetRequest\x1a\x34.systemathics.apis.services.set_static_data.v1.Asset\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x16/v1/staticdata/{asset}\x12\xa2\x01\n\x06GetOne\x12=.systemathics.apis.services.set_static_data.v1.AssetIdRequest\x1a\x34.systemathics.apis.services.set_static_data.v1.Asset\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/staticdata/{asset}/{id}\x12\x94\x01\n\x06GetAll\x12\x32.systemathics.apis.type.shared.v1.AssetTypeRequest\x1a\x34.systemathics.apis.services.set_static_data.v1.Asset\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/staticdata/{asset}0\x01\x12\x99\x01\n\x06Update\x12\x34.systemathics.apis.services.set_static_data.v1.Asset\x1a\x34.systemathics.apis.services.set_static_data.v1.Asset\"#\x82\xd3\xe4\x93\x02\x1d\x1a\x1b/v1/staticdata/{asset}/{id}\x12\x84\x01\n\x06\x44\x65lete\x12=.systemathics.apis.services.set_static_data.v1.AssetIdRequest\x1a\x16.google.protobuf.Empty\"#\x82\xd3\xe4\x93\x02\x1d*\x1b/v1/staticdata/{asset}/{id}B\x98\x02\n1com.systemathics.apis.services.set_static_data.v1B\x12SetStaticDataProtoP\x01\xa2\x02\x04SASS\xaa\x02+Systemathics.Apis.Services.SetStaticData.V1\xca\x02+Systemathics\\Apis\\Services\\SetStaticData\\V1\xe2\x02\x37Systemathics\\Apis\\Services\\SetStaticData\\V1\\GPBMetadata\xea\x02/Systemathics::Apis::Services::SetStaticData::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.static_data.v1.set_static_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n1com.systemathics.apis.services.set_static_data.v1B\022SetStaticDataProtoP\001\242\002\004SASS\252\002+Systemathics.Apis.Services.SetStaticData.V1\312\002+Systemathics\\Apis\\Services\\SetStaticData\\V1\342\0027Systemathics\\Apis\\Services\\SetStaticData\\V1\\GPBMetadata\352\002/Systemathics::Apis::Services::SetStaticData::V1'
  _globals['_SETSTATICDATASERVICE'].methods_by_name['Create']._options = None
  _globals['_SETSTATICDATASERVICE'].methods_by_name['Create']._serialized_options = b'\202\323\344\223\002\030\"\026/v1/staticdata/{asset}'
  _globals['_SETSTATICDATASERVICE'].methods_by_name['GetOne']._options = None
  _globals['_SETSTATICDATASERVICE'].methods_by_name['GetOne']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/staticdata/{asset}/{id}'
  _globals['_SETSTATICDATASERVICE'].methods_by_name['GetAll']._options = None
  _globals['_SETSTATICDATASERVICE'].methods_by_name['GetAll']._serialized_options = b'\202\323\344\223\002\030\022\026/v1/staticdata/{asset}'
  _globals['_SETSTATICDATASERVICE'].methods_by_name['Update']._options = None
  _globals['_SETSTATICDATASERVICE'].methods_by_name['Update']._serialized_options = b'\202\323\344\223\002\035\032\033/v1/staticdata/{asset}/{id}'
  _globals['_SETSTATICDATASERVICE'].methods_by_name['Delete']._options = None
  _globals['_SETSTATICDATASERVICE'].methods_by_name['Delete']._serialized_options = b'\202\323\344\223\002\035*\033/v1/staticdata/{asset}/{id}'
  _globals['_ASSETIDREQUEST']._serialized_start=364
  _globals['_ASSETIDREQUEST']._serialized_end=472
  _globals['_CREATEASSETREQUEST']._serialized_start=475
  _globals['_CREATEASSETREQUEST']._serialized_end=640
  _globals['_ASSET']._serialized_start=643
  _globals['_ASSET']._serialized_end=811
  _globals['_SETSTATICDATASERVICE']._serialized_start=814
  _globals['_SETSTATICDATASERVICE']._serialized_end=1607
# @@protoc_insertion_point(module_scope)
