# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily/v1/daily_market_data.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;systemathics/apis/services/daily/v1/daily_market_data.proto\x12#systemathics.apis.services.daily.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\"\xbb\x01\n\x16\x44\x61ilyMarketDataRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12S\n\rdate_interval\x18\x02 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\"c\n\x17\x44\x61ilyMarketDataResponse\x12H\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x34.systemathics.apis.services.daily.v1.DailyMarketDataR\x04\x64\x61ta\"\xed\x11\n\x0f\x44\x61ilyMarketData\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x12\n\x04open\x18\x02 \x01(\x01R\x04open\x12\x12\n\x04high\x18\x03 \x01(\x01R\x04high\x12\x10\n\x03low\x18\x04 \x01(\x01R\x03low\x12\x14\n\x05\x63lose\x18\x05 \x01(\x01R\x05\x63lose\x12\x16\n\x06volume\x18\x06 \x01(\x01R\x06volume\x12\x1b\n\tbid_price\x18\x07 \x01(\x01R\x08\x62idPrice\x12\x19\n\x08\x62id_size\x18\x08 \x01(\x01R\x07\x62idSize\x12\x1b\n\task_price\x18\t \x01(\x01R\x08\x61skPrice\x12\x19\n\x08\x61sk_size\x18\n \x01(\x01R\x07\x61skSize\x12\x14\n\x05\x64\x65lta\x18\x0b \x01(\x01R\x05\x64\x65lta\x12\x14\n\x05gamma\x18\x0c \x01(\x01R\x05gamma\x12\x14\n\x05theta\x18\r \x01(\x01R\x05theta\x12\x12\n\x04vega\x18\x0e \x01(\x01R\x04vega\x12\x10\n\x03rho\x18\x0f \x01(\x01R\x03rho\x12-\n\x12implied_volatility\x18\x10 \x01(\x01R\x11impliedVolatility\x12#\n\ropen_interest\x18\x11 \x01(\x01R\x0copenInterest\x12\x1e\n\nunderlying\x18\x12 \x01(\x01R\nunderlying\x12;\n\x1aimplied_volatility_30_call\x18\x13 \x01(\x01R\x17impliedVolatility30Call\x12\x39\n\x19implied_volatility_30_put\x18\x14 \x01(\x01R\x16impliedVolatility30Put\x12;\n\x1aimplied_volatility_30_mean\x18\x15 \x01(\x01R\x17impliedVolatility30Mean\x12;\n\x1aimplied_volatility_60_call\x18\x16 \x01(\x01R\x17impliedVolatility60Call\x12\x39\n\x19implied_volatility_60_put\x18\x17 \x01(\x01R\x16impliedVolatility60Put\x12;\n\x1aimplied_volatility_60_mean\x18\x18 \x01(\x01R\x17impliedVolatility60Mean\x12;\n\x1aimplied_volatility_90_call\x18\x19 \x01(\x01R\x17impliedVolatility90Call\x12\x39\n\x19implied_volatility_90_put\x18\x1a \x01(\x01R\x16impliedVolatility90Put\x12;\n\x1aimplied_volatility_90_mean\x18\x1b \x01(\x01R\x17impliedVolatility90Mean\x12=\n\x1bimplied_volatility_120_call\x18\x1c \x01(\x01R\x18impliedVolatility120Call\x12;\n\x1aimplied_volatility_120_put\x18\x1d \x01(\x01R\x17impliedVolatility120Put\x12=\n\x1bimplied_volatility_120_mean\x18\x1e \x01(\x01R\x18impliedVolatility120Mean\x12=\n\x1bimplied_volatility_150_call\x18\x1f \x01(\x01R\x18impliedVolatility150Call\x12;\n\x1aimplied_volatility_150_put\x18  \x01(\x01R\x17impliedVolatility150Put\x12=\n\x1bimplied_volatility_150_mean\x18! \x01(\x01R\x18impliedVolatility150Mean\x12=\n\x1bimplied_volatility_180_call\x18\" \x01(\x01R\x18impliedVolatility180Call\x12;\n\x1aimplied_volatility_180_put\x18# \x01(\x01R\x17impliedVolatility180Put\x12=\n\x1bimplied_volatility_180_mean\x18$ \x01(\x01R\x18impliedVolatility180Mean\x12=\n\x1bimplied_volatility_360_call\x18% \x01(\x01R\x18impliedVolatility360Call\x12;\n\x1aimplied_volatility_360_put\x18& \x01(\x01R\x17impliedVolatility360Put\x12=\n\x1bimplied_volatility_360_mean\x18\' \x01(\x01R\x18impliedVolatility360Mean\x12\x1f\n\x0b\x63\x61ll_volume\x18( \x01(\x01R\ncallVolume\x12\x1d\n\nput_volume\x18) \x01(\x01R\tputVolume\x12!\n\x0ctotal_volume\x18* \x01(\x01R\x0btotalVolume\x12,\n\x12\x63\x61ll_open_interest\x18+ \x01(\x01R\x10\x63\x61llOpenInterest\x12*\n\x11put_open_interest\x18, \x01(\x01R\x0fputOpenInterest\x12.\n\x13total_open_interest\x18- \x01(\x01R\x11totalOpenInterest\x12\x14\n\x05score\x18. \x01(\x01R\x05score\x12\x34\n\x16implied_volatility_bid\x18/ \x01(\x01R\x14impliedVolatilityBid\x12\x34\n\x16implied_volatility_ask\x18\x30 \x01(\x01R\x14impliedVolatilityAsk\x12\x36\n\x17implied_volatility_mean\x18\x31 \x01(\x01R\x15impliedVolatilityMean\x12#\n\roption_symbol\x18\x32 \x01(\tR\x0coptionSymbol\x12(\n\x10t1_open_interest\x18\x33 \x01(\x01R\x0et1OpenInterest2\xc5\x01\n\x16\x44\x61ilyMarketDataService\x12\xaa\x01\n\x0f\x44\x61ilyMarketData\x12;.systemathics.apis.services.daily.v1.DailyMarketDataRequest\x1a<.systemathics.apis.services.daily.v1.DailyMarketDataResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/daily/marketdataB\xf0\x01\n\'com.systemathics.apis.services.daily.v1B\x14\x44\x61ilyMarketDataProtoP\x01\xa2\x02\x04SASD\xaa\x02#Systemathics.Apis.Services.Daily.V1\xca\x02#Systemathics\\Apis\\Services\\Daily\\V1\xe2\x02/Systemathics\\Apis\\Services\\Daily\\V1\\GPBMetadata\xea\x02\'Systemathics::Apis::Services::Daily::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily.v1.daily_market_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.systemathics.apis.services.daily.v1B\024DailyMarketDataProtoP\001\242\002\004SASD\252\002#Systemathics.Apis.Services.Daily.V1\312\002#Systemathics\\Apis\\Services\\Daily\\V1\342\002/Systemathics\\Apis\\Services\\Daily\\V1\\GPBMetadata\352\002\'Systemathics::Apis::Services::Daily::V1'
  _globals['_DAILYMARKETDATASERVICE'].methods_by_name['DailyMarketData']._options = None
  _globals['_DAILYMARKETDATASERVICE'].methods_by_name['DailyMarketData']._serialized_options = b'\202\323\344\223\002\026\022\024/v1/daily/marketdata'
  _globals['_DAILYMARKETDATAREQUEST']._serialized_start=260
  _globals['_DAILYMARKETDATAREQUEST']._serialized_end=447
  _globals['_DAILYMARKETDATARESPONSE']._serialized_start=449
  _globals['_DAILYMARKETDATARESPONSE']._serialized_end=548
  _globals['_DAILYMARKETDATA']._serialized_start=551
  _globals['_DAILYMARKETDATA']._serialized_end=2836
  _globals['_DAILYMARKETDATASERVICE']._serialized_start=2839
  _globals['_DAILYMARKETDATASERVICE']._serialized_end=3036
# @@protoc_insertion_point(module_scope)
