# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/static_data/v1/static_data_set.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.services.static_data.v1 import static_data_pb2 as systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_static__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?systemathics/apis/services/static_data/v1/static_data_set.proto\x12)systemathics.apis.services.static_data.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a;systemathics/apis/services/static_data/v1/static_data.proto\"\x8a\x03\n\x1dStaticDataOtcStreamingRequest\x12\x16\n\x06ticker\x18\x01 \x01(\tR\x06ticker\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\x12\x16\n\x06strike\x18\x03 \x01(\x01R\x06strike\x12\\\n\rswaption_type\x18\x04 \x01(\x0e\x32\x37.systemathics.apis.services.static_data.v1.SwaptionTypeR\x0cswaptionType\x12)\n\x06\x65xpiry\x18\x05 \x01(\x0b\x32\x11.google.type.DateR\x06\x65xpiry\x12+\n\x11underlying_ticker\x18\x06 \x01(\tR\x10underlyingTicker\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x1b\n\tmarkit_id\x18\x08 \x01(\tR\x08markitId\x12\x12\n\x04\x66igi\x18\t \x01(\tR\x04\x66igi\x12\x1a\n\x08\x63\x61lendar\x18\n \x01(\tR\x08\x63\x61lendar2\xbf\x01\n\x14StaticDataSetService\x12\xa6\x01\n\x1c\x43reateStaticDataOtcStreaming\x12H.systemathics.apis.services.static_data.v1.StaticDataOtcStreamingRequest\x1a\x16.google.protobuf.Empty\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/staticdata/otc_streamingB\x88\x02\n-com.systemathics.apis.services.static_data.v1B\x12StaticDataSetProtoP\x01\xa2\x02\x04SASS\xaa\x02(Systemathics.Apis.Services.StaticData.V1\xca\x02(Systemathics\\Apis\\Services\\StaticData\\V1\xe2\x02\x34Systemathics\\Apis\\Services\\StaticData\\V1\\GPBMetadata\xea\x02,Systemathics::Apis::Services::StaticData::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.static_data.v1.static_data_set_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-com.systemathics.apis.services.static_data.v1B\022StaticDataSetProtoP\001\242\002\004SASS\252\002(Systemathics.Apis.Services.StaticData.V1\312\002(Systemathics\\Apis\\Services\\StaticData\\V1\342\0024Systemathics\\Apis\\Services\\StaticData\\V1\\GPBMetadata\352\002,Systemathics::Apis::Services::StaticData::V1'
  _globals['_STATICDATASETSERVICE'].methods_by_name['CreateStaticDataOtcStreaming']._options = None
  _globals['_STATICDATASETSERVICE'].methods_by_name['CreateStaticDataOtcStreaming']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/staticdata/otc_streaming'
  _globals['_STATICDATAOTCSTREAMINGREQUEST']._serialized_start=255
  _globals['_STATICDATAOTCSTREAMINGREQUEST']._serialized_end=649
  _globals['_STATICDATASETSERVICE']._serialized_start=652
  _globals['_STATICDATASETSERVICE']._serialized_end=843
# @@protoc_insertion_point(module_scope)
