# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/calendar/v1/calendar.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from google.type import datetime_pb2 as google_dot_type_dot_datetime__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5systemathics/apis/services/calendar/v1/calendar.proto\x12&systemathics.apis.services.calendar.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a\x1bgoogle/type/timeofday.proto\x1a\x1agoogle/type/datetime.proto\x1a\x1bgoogle/protobuf/empty.proto\"p\n\x19HolidayCodeToMicsResponse\x12S\n\x05items\x18\x01 \x03(\x0b\x32=.systemathics.apis.services.calendar.v1.HolidayCodeToMicsItemR\x05items\"N\n\x15HolidayCodeToMicsItem\x12!\n\x0choliday_code\x18\x01 \x01(\tR\x0bholidayCode\x12\x12\n\x04mics\x18\x02 \x03(\tR\x04mics\"p\n\x19MicToHolidayCodesResponse\x12S\n\x05items\x18\x01 \x03(\x0b\x32=.systemathics.apis.services.calendar.v1.MicToHolidayCodesItemR\x05items\"N\n\x15MicToHolidayCodesItem\x12\x10\n\x03mic\x18\x01 \x01(\tR\x03mic\x12#\n\rholiday_codes\x18\x02 \x03(\tR\x0cholidayCodes\"\x90\x02\n\x10TradingHoursItem\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x16\n\x06market\x18\x02 \x01(\tR\x06market\x12\x46\n\x04type\x18\x03 \x01(\x0e\x32\x32.systemathics.apis.services.calendar.v1.MarketTypeR\x04type\x12!\n\x0choliday_code\x18\x04 \x01(\tR\x0bholidayCode\x12R\n\x05hours\x18\x05 \x03(\x0b\x32<.systemathics.apis.services.calendar.v1.TradingHoursActivityR\x05hours\"\xb2\x06\n\x14TradingHoursActivity\x12\x1a\n\x08\x61\x63tivity\x18\x01 \x01(\tR\x08\x61\x63tivity\x12\x1c\n\tfunctions\x18\x02 \x03(\tR\tfunctions\x12O\n\tirregular\x18\x03 \x01(\x0e\x32\x31.systemathics.apis.services.calendar.v1.IrregularR\tirregular\x12\x1b\n\tnew_hours\x18\x04 \x01(\x08R\x08newHours\x12>\n\x0flocal_open_time\x18\x05 \x01(\x0b\x32\x16.google.type.TimeOfDayR\rlocalOpenTime\x12@\n\x10local_close_time\x18\x06 \x01(\x0b\x32\x16.google.type.TimeOfDayR\x0elocalCloseTime\x12\\\n\x1cvariable_seconds_before_open\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x19variableSecondsBeforeOpen\x12Z\n\x1bvariable_seconds_after_open\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x18variableSecondsAfterOpen\x12^\n\x1dvariable_seconds_before_close\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x1avariableSecondsBeforeClose\x12\\\n\x1cvariable_seconds_after_close\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x19variableSecondsAfterClose\x12:\n\rutc_open_time\x18\x0b \x01(\x0b\x32\x16.google.type.TimeOfDayR\x0butcOpenTime\x12<\n\x0eutc_close_time\x18\x0c \x01(\x0b\x32\x16.google.type.TimeOfDayR\x0cutcCloseTime\"f\n\x14TradingHoursResponse\x12N\n\x05items\x18\x01 \x03(\x0b\x32\x38.systemathics.apis.services.calendar.v1.TradingHoursItemR\x05items\"\'\n\x13TradingHoursRequest\x12\x10\n\x03mic\x18\x01 \x01(\tR\x03mic\"-\n\x17TradingHoursMicResponse\x12\x12\n\x04mics\x18\x01 \x03(\tR\x04mics\"2\n\x14HolidayCenterRequest\x12\x1a\n\x08\x63urrency\x18\x01 \x01(\tR\x08\x63urrency\";\n\x18HolidaysAsOfDatesRequest\x12\x1f\n\x0b\x63\x65nter_code\x18\x01 \x01(\tR\ncenterCode\"g\n\x0fHolidaysRequest\x12\x1f\n\x0b\x63\x65nter_code\x18\x01 \x01(\tR\ncenterCode\x12\x33\n\nas_of_date\x18\x02 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x61sOfDate\"h\n\x15HolidayCenterResponse\x12O\n\x05items\x18\x01 \x03(\x0b\x32\x39.systemathics.apis.services.calendar.v1.HolidayCenterItemR\x05items\"\x9e\x02\n\x11HolidayCenterItem\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x18\n\x07\x63ountry\x18\x03 \x01(\tR\x07\x63ountry\x12\x1a\n\x08\x63urrency\x18\x04 \x01(\tR\x08\x63urrency\x12V\n\x0choliday_type\x18\x05 \x01(\x0e\x32\x33.systemathics.apis.services.calendar.v1.HolidayTypeR\x0bholidayType\x12\x1f\n\x0biso_country\x18\x06 \x01(\tR\nisoCountry\x12\x1e\n\ndefinition\x18\x07 \x01(\tR\ndefinition\x12\x12\n\x04mics\x18\x08 \x03(\tR\x04mics\";\n\x19HolidayCurrenciesResponse\x12\x1e\n\ncurrencies\x18\x01 \x03(\tR\ncurrencies\"L\n\x0bHolidayItem\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"R\n\x19HolidaysAsOfDatesResponse\x12\x35\n\x0b\x61s_of_dates\x18\x01 \x03(\x0b\x32\x15.google.type.DateTimeR\tasOfDates\"\xc4\x01\n\x10HolidaysResponse\x12Z\n\x0b\x63\x65nter_info\x18\x01 \x01(\x0b\x32\x39.systemathics.apis.services.calendar.v1.HolidayCenterItemR\ncenterInfo\x12T\n\x0b\x63losed_days\x18\x02 \x03(\x0b\x32\x33.systemathics.apis.services.calendar.v1.HolidayItemR\nclosedDays*z\n\tIrregular\x12\x19\n\x15IRREGULAR_UNSPECIFIED\x10\x00\x12\x11\n\rIRREGULAR_YES\x10\x01\x12\x10\n\x0cIRREGULAR_NO\x10\x02\x12\x16\n\x12IRREGULAR_WEEK_END\x10\x03\x12\x15\n\x11IRREGULAR_HOLIDAY\x10\x04*\xe9\x01\n\nMarketType\x12\x1b\n\x17MARKET_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17MARKET_TYPE_CASH_EQUITY\x10\x01\x12 \n\x1cMARKET_TYPE_FUTURES_CONTRACT\x10\x02\x12\"\n\x1eMARKET_TYPE_OPTIONS_ON_FUTURES\x10\x03\x12%\n!MARKET_TYPE_OPTIONS_ON_SECURITIES\x10\x04\x12\x1d\n\x19MARKET_TYPE_OTHER_OPTIONS\x10\x05\x12\x15\n\x11MARKET_TYPE_OTHER\x10\x06*\xd1\x01\n\x0bHolidayType\x12\x1c\n\x18HOLIDAY_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11HOLIDAY_TYPE_BANK\x10\x01\x12 \n\x1cHOLIDAY_TYPE_FUTURES_TRADING\x10\x02\x12\x16\n\x12HOLIDAY_TYPE_OTHER\x10\x03\x12*\n&HOLIDAY_TYPE_STOCK_EXCHANGE_SETTLEMENT\x10\x04\x12\'\n#HOLIDAY_TYPE_STOCK_EXCHANGE_TRADING\x10\x05\x32\xc2\n\n\x0f\x43\x61lendarService\x12\x98\x01\n\x11HolidayCurrencies\x12\x16.google.protobuf.Empty\x1a\x41.systemathics.apis.services.calendar.v1.HolidayCurrenciesResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/calendar/holidays/currencies\x12\xb2\x01\n\rHolidayCenter\x12<.systemathics.apis.services.calendar.v1.HolidayCenterRequest\x1a=.systemathics.apis.services.calendar.v1.HolidayCenterResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/calendar/holidays/center\x12\xc3\x01\n\x11HolidaysAsOfDates\x12@.systemathics.apis.services.calendar.v1.HolidaysAsOfDatesRequest\x1a\x41.systemathics.apis.services.calendar.v1.HolidaysAsOfDatesResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/calendar/holidays_as_of_dates\x12\x9c\x01\n\x08Holidays\x12\x37.systemathics.apis.services.calendar.v1.HolidaysRequest\x1a\x38.systemathics.apis.services.calendar.v1.HolidaysResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/calendar/holidays\x12\x93\x01\n\x0fTradingHoursMic\x12\x16.google.protobuf.Empty\x1a?.systemathics.apis.services.calendar.v1.TradingHoursMicResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/calendar/trading_hours/mics\x12\xad\x01\n\x0cTradingHours\x12;.systemathics.apis.services.calendar.v1.TradingHoursRequest\x1a<.systemathics.apis.services.calendar.v1.TradingHoursResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/calendar/trading_hours\x12\x98\x01\n\x11HolidayCodeToMics\x12\x16.google.protobuf.Empty\x1a\x41.systemathics.apis.services.calendar.v1.HolidayCodeToMicsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/calendar/holiday_code_2_mics\x12\x98\x01\n\x11MicToHolidayCodes\x12\x16.google.protobuf.Empty\x1a\x41.systemathics.apis.services.calendar.v1.MicToHolidayCodesResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/calendar/mic_2_holiday_codesB\xf8\x01\n*com.systemathics.apis.services.calendar.v1B\rCalendarProtoP\x01\xa2\x02\x04SASC\xaa\x02&Systemathics.Apis.Services.Calendar.V1\xca\x02&Systemathics\\Apis\\Services\\Calendar\\V1\xe2\x02\x32Systemathics\\Apis\\Services\\Calendar\\V1\\GPBMetadata\xea\x02*Systemathics::Apis::Services::Calendar::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.calendar.v1.calendar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.systemathics.apis.services.calendar.v1B\rCalendarProtoP\001\242\002\004SASC\252\002&Systemathics.Apis.Services.Calendar.V1\312\002&Systemathics\\Apis\\Services\\Calendar\\V1\342\0022Systemathics\\Apis\\Services\\Calendar\\V1\\GPBMetadata\352\002*Systemathics::Apis::Services::Calendar::V1'
  _globals['_CALENDARSERVICE'].methods_by_name['HolidayCurrencies']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['HolidayCurrencies']._serialized_options = b'\202\323\344\223\002\"\022 /v1/calendar/holidays/currencies'
  _globals['_CALENDARSERVICE'].methods_by_name['HolidayCenter']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['HolidayCenter']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/calendar/holidays/center'
  _globals['_CALENDARSERVICE'].methods_by_name['HolidaysAsOfDates']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['HolidaysAsOfDates']._serialized_options = b'\202\323\344\223\002#\022!/v1/calendar/holidays_as_of_dates'
  _globals['_CALENDARSERVICE'].methods_by_name['Holidays']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['Holidays']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/calendar/holidays'
  _globals['_CALENDARSERVICE'].methods_by_name['TradingHoursMic']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['TradingHoursMic']._serialized_options = b'\202\323\344\223\002!\022\037/v1/calendar/trading_hours/mics'
  _globals['_CALENDARSERVICE'].methods_by_name['TradingHours']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['TradingHours']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/calendar/trading_hours'
  _globals['_CALENDARSERVICE'].methods_by_name['HolidayCodeToMics']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['HolidayCodeToMics']._serialized_options = b'\202\323\344\223\002\"\022 /v1/calendar/holiday_code_2_mics'
  _globals['_CALENDARSERVICE'].methods_by_name['MicToHolidayCodes']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['MicToHolidayCodes']._serialized_options = b'\202\323\344\223\002\"\022 /v1/calendar/mic_2_holiday_codes'
  _globals['_IRREGULAR']._serialized_start=2980
  _globals['_IRREGULAR']._serialized_end=3102
  _globals['_MARKETTYPE']._serialized_start=3105
  _globals['_MARKETTYPE']._serialized_end=3338
  _globals['_HOLIDAYTYPE']._serialized_start=3341
  _globals['_HOLIDAYTYPE']._serialized_end=3550
  _globals['_HOLIDAYCODETOMICSRESPONSE']._serialized_start=269
  _globals['_HOLIDAYCODETOMICSRESPONSE']._serialized_end=381
  _globals['_HOLIDAYCODETOMICSITEM']._serialized_start=383
  _globals['_HOLIDAYCODETOMICSITEM']._serialized_end=461
  _globals['_MICTOHOLIDAYCODESRESPONSE']._serialized_start=463
  _globals['_MICTOHOLIDAYCODESRESPONSE']._serialized_end=575
  _globals['_MICTOHOLIDAYCODESITEM']._serialized_start=577
  _globals['_MICTOHOLIDAYCODESITEM']._serialized_end=655
  _globals['_TRADINGHOURSITEM']._serialized_start=658
  _globals['_TRADINGHOURSITEM']._serialized_end=930
  _globals['_TRADINGHOURSACTIVITY']._serialized_start=933
  _globals['_TRADINGHOURSACTIVITY']._serialized_end=1751
  _globals['_TRADINGHOURSRESPONSE']._serialized_start=1753
  _globals['_TRADINGHOURSRESPONSE']._serialized_end=1855
  _globals['_TRADINGHOURSREQUEST']._serialized_start=1857
  _globals['_TRADINGHOURSREQUEST']._serialized_end=1896
  _globals['_TRADINGHOURSMICRESPONSE']._serialized_start=1898
  _globals['_TRADINGHOURSMICRESPONSE']._serialized_end=1943
  _globals['_HOLIDAYCENTERREQUEST']._serialized_start=1945
  _globals['_HOLIDAYCENTERREQUEST']._serialized_end=1995
  _globals['_HOLIDAYSASOFDATESREQUEST']._serialized_start=1997
  _globals['_HOLIDAYSASOFDATESREQUEST']._serialized_end=2056
  _globals['_HOLIDAYSREQUEST']._serialized_start=2058
  _globals['_HOLIDAYSREQUEST']._serialized_end=2161
  _globals['_HOLIDAYCENTERRESPONSE']._serialized_start=2163
  _globals['_HOLIDAYCENTERRESPONSE']._serialized_end=2267
  _globals['_HOLIDAYCENTERITEM']._serialized_start=2270
  _globals['_HOLIDAYCENTERITEM']._serialized_end=2556
  _globals['_HOLIDAYCURRENCIESRESPONSE']._serialized_start=2558
  _globals['_HOLIDAYCURRENCIESRESPONSE']._serialized_end=2617
  _globals['_HOLIDAYITEM']._serialized_start=2619
  _globals['_HOLIDAYITEM']._serialized_end=2695
  _globals['_HOLIDAYSASOFDATESRESPONSE']._serialized_start=2697
  _globals['_HOLIDAYSASOFDATESRESPONSE']._serialized_end=2779
  _globals['_HOLIDAYSRESPONSE']._serialized_start=2782
  _globals['_HOLIDAYSRESPONSE']._serialized_end=2978
  _globals['_CALENDARSERVICE']._serialized_start=3553
  _globals['_CALENDARSERVICE']._serialized_end=4899
# @@protoc_insertion_point(module_scope)
