# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily/v1/daily_market_data_by_underlying.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import option_type_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_option__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIsystemathics/apis/services/daily/v1/daily_market_data_by_underlying.proto\x12#systemathics.apis.services.daily.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/option_type.proto\"\xae\x01\n\"DailyMarketDataByUnderlyingRequest\x12\x61\n\x15underlying_identifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\x14underlyingIdentifier\x12%\n\x04\x64\x61te\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\"{\n#DailyMarketDataByUnderlyingResponse\x12T\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32@.systemathics.apis.services.daily.v1.DailyMarketDataByUnderlyingR\x04\x64\x61ta\"\xb8\x06\n\x1b\x44\x61ilyMarketDataByUnderlying\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12+\n\x11underlying_symbol\x18\x02 \x01(\tR\x10underlyingSymbol\x12)\n\x10underlying_price\x18\x03 \x01(\x01R\x0funderlyingPrice\x12#\n\roption_symbol\x18\x04 \x01(\tR\x0coptionSymbol\x12M\n\x0boption_type\x18\x05 \x01(\x0e\x32,.systemathics.apis.type.shared.v1.OptionTypeR\noptionType\x12#\n\roption_strike\x18\x06 \x01(\x01R\x0coptionStrike\x12G\n\x16option_expiration_date\x18\x07 \x01(\x0b\x32\x11.google.type.DateR\x14optionExpirationDate\x12\x1d\n\nlast_price\x18\x08 \x01(\x01R\tlastPrice\x12\x1b\n\tbid_price\x18\t \x01(\x01R\x08\x62idPrice\x12\x1b\n\task_price\x18\n \x01(\x01R\x08\x61skPrice\x12\x16\n\x06volume\x18\x0b \x01(\x01R\x06volume\x12#\n\ropen_interest\x18\x0c \x01(\x01R\x0copenInterest\x12(\n\x10t1_open_interest\x18\r \x01(\x01R\x0et1OpenInterest\x12\x14\n\x05\x64\x65lta\x18\x0e \x01(\x01R\x05\x64\x65lta\x12\x14\n\x05gamma\x18\x0f \x01(\x01R\x05gamma\x12\x14\n\x05theta\x18\x10 \x01(\x01R\x05theta\x12\x12\n\x04vega\x18\x11 \x01(\x01R\x04vega\x12\x34\n\x16implied_volatility_bid\x18\x12 \x01(\x01R\x14impliedVolatilityBid\x12\x34\n\x16implied_volatility_ask\x18\x13 \x01(\x01R\x14impliedVolatilityAsk\x12\x36\n\x17implied_volatility_mean\x18\x14 \x01(\x01R\x15impliedVolatilityMean2\x83\x02\n\"DailyMarketDataByUnderlyingService\x12\xdc\x01\n\x1b\x44\x61ilyMarketDataByUnderlying\x12G.systemathics.apis.services.daily.v1.DailyMarketDataByUnderlyingRequest\x1aH.systemathics.apis.services.daily.v1.DailyMarketDataByUnderlyingResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/daily/marketdata_by_underlyingB\xfc\x01\n\'com.systemathics.apis.services.daily.v1B DailyMarketDataByUnderlyingProtoP\x01\xa2\x02\x04SASD\xaa\x02#Systemathics.Apis.Services.Daily.V1\xca\x02#Systemathics\\Apis\\Services\\Daily\\V1\xe2\x02/Systemathics\\Apis\\Services\\Daily\\V1\\GPBMetadata\xea\x02\'Systemathics::Apis::Services::Daily::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily.v1.daily_market_data_by_underlying_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.systemathics.apis.services.daily.v1B DailyMarketDataByUnderlyingProtoP\001\242\002\004SASD\252\002#Systemathics.Apis.Services.Daily.V1\312\002#Systemathics\\Apis\\Services\\Daily\\V1\342\002/Systemathics\\Apis\\Services\\Daily\\V1\\GPBMetadata\352\002\'Systemathics::Apis::Services::Daily::V1'
  _globals['_DAILYMARKETDATABYUNDERLYINGSERVICE'].methods_by_name['DailyMarketDataByUnderlying']._options = None
  _globals['_DAILYMARKETDATABYUNDERLYINGSERVICE'].methods_by_name['DailyMarketDataByUnderlying']._serialized_options = b'\202\323\344\223\002$\022\"/v1/daily/marketdata_by_underlying'
  _globals['_DAILYMARKETDATABYUNDERLYINGREQUEST']._serialized_start=272
  _globals['_DAILYMARKETDATABYUNDERLYINGREQUEST']._serialized_end=446
  _globals['_DAILYMARKETDATABYUNDERLYINGRESPONSE']._serialized_start=448
  _globals['_DAILYMARKETDATABYUNDERLYINGRESPONSE']._serialized_end=571
  _globals['_DAILYMARKETDATABYUNDERLYING']._serialized_start=574
  _globals['_DAILYMARKETDATABYUNDERLYING']._serialized_end=1398
  _globals['_DAILYMARKETDATABYUNDERLYINGSERVICE']._serialized_start=1401
  _globals['_DAILYMARKETDATABYUNDERLYINGSERVICE']._serialized_end=1660
# @@protoc_insertion_point(module_scope)
