# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v2/set_tick.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import datetime_pb2 as google_dot_type_dot_datetime__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v2 import set_data_mode_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_set__data__mode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1systemathics/apis/services/tick/v2/set_tick.proto\x12\"systemathics.apis.services.tick.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1agoogle/type/datetime.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x34systemathics/apis/type/shared/v2/set_data_mode.proto\"\xa8\x02\n\x14SetTickScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x31\n\x08\x64\x61tetime\x18\x02 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12V\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x42.systemathics.apis.services.tick.v2.SetTickScalarRequest.DataEntryR\x04\x64\x61ta\x1a\x37\n\tDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xbb\x01\n\x1aSetTickScalarStreamRequest\x12\x45\n\x04info\x18\x01 \x01(\x0b\x32/.systemathics.apis.services.tick.v2.SetTickInfoH\x00R\x04info\x12K\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.systemathics.apis.services.tick.v2.SetTickScalarDataH\x00R\x04\x64\x61taB\t\n\x07payload\"\xba\x02\n\x14SetTickVectorRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x31\n\x08\x64\x61tetime\x18\x02 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x10\n\x03key\x18\x03 \x01(\tR\x03key\x12V\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\x42.systemathics.apis.services.tick.v2.SetTickVectorRequest.DataEntryR\x04\x64\x61ta\x1a\x37\n\tDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xbb\x01\n\x1aSetTickVectorStreamRequest\x12\x45\n\x04info\x18\x01 \x01(\x0b\x32/.systemathics.apis.services.tick.v2.SetTickInfoH\x00R\x04info\x12K\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.systemathics.apis.services.tick.v2.SetTickVectorDataH\x00R\x04\x64\x61taB\t\n\x07payload\"\xac\x01\n\x17\x44\x65leteTickScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12+\n\x05\x64\x61tes\x18\x03 \x03(\x0b\x32\x15.google.type.DateTimeR\x05\x64\x61tes\"\xc2\x01\n\x17\x44\x65leteTickVectorRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12\x41\n\x04keys\x18\x03 \x03(\x0b\x32-.systemathics.apis.services.tick.v2.VectorKeyR\x04keys\"s\n\x0bSetTickInfo\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\"Z\n\x11SetTickScalarData\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x01R\x04\x64\x61ta\"P\n\tVectorKey\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\"l\n\x11SetTickVectorData\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\x12\x12\n\x04\x64\x61ta\x18\x03 \x03(\x01R\x04\x64\x61ta2\xc6\n\n\x0eSetTickService\x12|\n\x0fWriteTickScalar\x12\x38.systemathics.apis.services.tick.v2.SetTickScalarRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0f/v2/tick_scalar\x12\x8a\x01\n\x15WriteTickScalarStream\x12>.systemathics.apis.services.tick.v2.SetTickScalarStreamRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0f/v2/tick_scalar(\x01\x12|\n\x0fWriteTickVector\x12\x38.systemathics.apis.services.tick.v2.SetTickVectorRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0f/v2/tick_vector\x12\x8a\x01\n\x15WriteTickVectorStream\x12>.systemathics.apis.services.tick.v2.SetTickVectorStreamRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0f/v2/tick_vector(\x01\x12}\n\x10UpdateTickScalar\x12\x38.systemathics.apis.services.tick.v2.SetTickScalarRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\x1a\x0f/v2/tick_scalar\x12\x8b\x01\n\x16UpdateTickScalarStream\x12>.systemathics.apis.services.tick.v2.SetTickScalarStreamRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\x1a\x0f/v2/tick_scalar(\x01\x12}\n\x10UpdateTickVector\x12\x38.systemathics.apis.services.tick.v2.SetTickVectorRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\x1a\x0f/v2/tick_vector\x12\x8b\x01\n\x16UpdateTickVectorStream\x12>.systemathics.apis.services.tick.v2.SetTickVectorStreamRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\x1a\x0f/v2/tick_vector(\x01\x12\x80\x01\n\x10\x44\x65leteTickScalar\x12;.systemathics.apis.services.tick.v2.DeleteTickScalarRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11*\x0f/v2/tick_scalar\x12\x80\x01\n\x10\x44\x65leteTickVector\x12;.systemathics.apis.services.tick.v2.DeleteTickVectorRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11*\x0f/v2/tick_vectorB\xe3\x01\n&com.systemathics.apis.services.tick.v2B\x0cSetTickProtoP\x01\xa2\x02\x04SAST\xaa\x02\"Systemathics.Apis.Services.Tick.V2\xca\x02\"Systemathics\\Apis\\Services\\Tick\\V2\xe2\x02.Systemathics\\Apis\\Services\\Tick\\V2\\GPBMetadata\xea\x02&Systemathics::Apis::Services::Tick::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick.v2.set_tick_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.systemathics.apis.services.tick.v2B\014SetTickProtoP\001\242\002\004SAST\252\002\"Systemathics.Apis.Services.Tick.V2\312\002\"Systemathics\\Apis\\Services\\Tick\\V2\342\002.Systemathics\\Apis\\Services\\Tick\\V2\\GPBMetadata\352\002&Systemathics::Apis::Services::Tick::V2'
  _globals['_SETTICKSCALARREQUEST_DATAENTRY']._options = None
  _globals['_SETTICKSCALARREQUEST_DATAENTRY']._serialized_options = b'8\001'
  _globals['_SETTICKVECTORREQUEST_DATAENTRY']._options = None
  _globals['_SETTICKVECTORREQUEST_DATAENTRY']._serialized_options = b'8\001'
  _globals['_SETTICKSERVICE'].methods_by_name['WriteTickScalar']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['WriteTickScalar']._serialized_options = b'\202\323\344\223\002\021\"\017/v2/tick_scalar'
  _globals['_SETTICKSERVICE'].methods_by_name['WriteTickScalarStream']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['WriteTickScalarStream']._serialized_options = b'\202\323\344\223\002\021\"\017/v2/tick_scalar'
  _globals['_SETTICKSERVICE'].methods_by_name['WriteTickVector']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['WriteTickVector']._serialized_options = b'\202\323\344\223\002\021\"\017/v2/tick_vector'
  _globals['_SETTICKSERVICE'].methods_by_name['WriteTickVectorStream']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['WriteTickVectorStream']._serialized_options = b'\202\323\344\223\002\021\"\017/v2/tick_vector'
  _globals['_SETTICKSERVICE'].methods_by_name['UpdateTickScalar']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['UpdateTickScalar']._serialized_options = b'\202\323\344\223\002\021\032\017/v2/tick_scalar'
  _globals['_SETTICKSERVICE'].methods_by_name['UpdateTickScalarStream']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['UpdateTickScalarStream']._serialized_options = b'\202\323\344\223\002\021\032\017/v2/tick_scalar'
  _globals['_SETTICKSERVICE'].methods_by_name['UpdateTickVector']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['UpdateTickVector']._serialized_options = b'\202\323\344\223\002\021\032\017/v2/tick_vector'
  _globals['_SETTICKSERVICE'].methods_by_name['UpdateTickVectorStream']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['UpdateTickVectorStream']._serialized_options = b'\202\323\344\223\002\021\032\017/v2/tick_vector'
  _globals['_SETTICKSERVICE'].methods_by_name['DeleteTickScalar']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['DeleteTickScalar']._serialized_options = b'\202\323\344\223\002\021*\017/v2/tick_scalar'
  _globals['_SETTICKSERVICE'].methods_by_name['DeleteTickVector']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['DeleteTickVector']._serialized_options = b'\202\323\344\223\002\021*\017/v2/tick_vector'
  _globals['_SETTICKSCALARREQUEST']._serialized_start=410
  _globals['_SETTICKSCALARREQUEST']._serialized_end=706
  _globals['_SETTICKSCALARREQUEST_DATAENTRY']._serialized_start=651
  _globals['_SETTICKSCALARREQUEST_DATAENTRY']._serialized_end=706
  _globals['_SETTICKSCALARSTREAMREQUEST']._serialized_start=709
  _globals['_SETTICKSCALARSTREAMREQUEST']._serialized_end=896
  _globals['_SETTICKVECTORREQUEST']._serialized_start=899
  _globals['_SETTICKVECTORREQUEST']._serialized_end=1213
  _globals['_SETTICKVECTORREQUEST_DATAENTRY']._serialized_start=651
  _globals['_SETTICKVECTORREQUEST_DATAENTRY']._serialized_end=706
  _globals['_SETTICKVECTORSTREAMREQUEST']._serialized_start=1216
  _globals['_SETTICKVECTORSTREAMREQUEST']._serialized_end=1403
  _globals['_DELETETICKSCALARREQUEST']._serialized_start=1406
  _globals['_DELETETICKSCALARREQUEST']._serialized_end=1578
  _globals['_DELETETICKVECTORREQUEST']._serialized_start=1581
  _globals['_DELETETICKVECTORREQUEST']._serialized_end=1775
  _globals['_SETTICKINFO']._serialized_start=1777
  _globals['_SETTICKINFO']._serialized_end=1892
  _globals['_SETTICKSCALARDATA']._serialized_start=1894
  _globals['_SETTICKSCALARDATA']._serialized_end=1984
  _globals['_VECTORKEY']._serialized_start=1986
  _globals['_VECTORKEY']._serialized_end=2066
  _globals['_SETTICKVECTORDATA']._serialized_start=2068
  _globals['_SETTICKVECTORDATA']._serialized_end=2176
  _globals['_SETTICKSERVICE']._serialized_start=2179
  _globals['_SETTICKSERVICE']._serialized_end=3529
# @@protoc_insertion_point(module_scope)
