# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v2/set_data_mode.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4systemathics/apis/type/shared/v2/set_data_mode.proto\x12 systemathics.apis.type.shared.v2*|\n\x0bSetDataMode\x12\x1d\n\x19SET_DATA_MODE_UNSPECIFIED\x10\x00\x12\x17\n\x13SET_DATA_MODE_WRITE\x10\x01\x12\x18\n\x14SET_DATA_MODE_APPEND\x10\x02\x12\x1b\n\x17SET_DATA_MODE_OVERWRITE\x10\x03\x42\xdd\x01\n$com.systemathics.apis.type.shared.v2B\x10SetDataModeProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V2\xca\x02 Systemathics\\Apis\\Type\\Shared\\V2\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V2\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v2.set_data_mode_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v2B\020SetDataModeProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V2\312\002 Systemathics\\Apis\\Type\\Shared\\V2\342\002,Systemathics\\Apis\\Type\\Shared\\V2\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V2'
  _globals['_SETDATAMODE']._serialized_start=90
  _globals['_SETDATAMODE']._serialized_end=214
# @@protoc_insertion_point(module_scope)
