# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily/v2/set_daily.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v2 import set_data_mode_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_set__data__mode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3systemathics/apis/services/daily/v2/set_daily.proto\x12#systemathics.apis.services.daily.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x34systemathics/apis/type/shared/v2/set_data_mode.proto\"\x9f\x02\n\x15SetDailyScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12%\n\x04\x64\x61te\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12X\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x44.systemathics.apis.services.daily.v2.SetDailyScalarRequest.DataEntryR\x04\x64\x61ta\x1a\x37\n\tDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xc0\x01\n\x1bSetDailyScalarStreamRequest\x12G\n\x04info\x18\x01 \x01(\x0b\x32\x31.systemathics.apis.services.daily.v2.SetDailyInfoH\x00R\x04info\x12M\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x37.systemathics.apis.services.daily.v2.SetDailyScalarDataH\x00R\x04\x64\x61taB\t\n\x07payload\"\xb1\x02\n\x15SetDailyVectorRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12%\n\x04\x64\x61te\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x10\n\x03key\x18\x03 \x01(\tR\x03key\x12X\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\x44.systemathics.apis.services.daily.v2.SetDailyVectorRequest.DataEntryR\x04\x64\x61ta\x1a\x37\n\tDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xc0\x01\n\x1bSetDailyVectorStreamRequest\x12G\n\x04info\x18\x01 \x01(\x0b\x32\x31.systemathics.apis.services.daily.v2.SetDailyInfoH\x00R\x04info\x12M\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x37.systemathics.apis.services.daily.v2.SetDailyVectorDataH\x00R\x04\x64\x61taB\t\n\x07payload\"\xa9\x01\n\x18\x44\x65leteDailyScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12\'\n\x05\x64\x61tes\x18\x03 \x03(\x0b\x32\x11.google.type.DateR\x05\x64\x61tes\"\xc4\x01\n\x18\x44\x65leteDailyVectorRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12\x42\n\x04keys\x18\x03 \x03(\x0b\x32..systemathics.apis.services.daily.v2.VectorKeyR\x04keys\"t\n\x0cSetDailyInfo\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\"O\n\x12SetDailyScalarData\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x01R\x04\x64\x61ta\"D\n\tVectorKey\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\"a\n\x12SetDailyVectorData\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\x12\x12\n\x04\x64\x61ta\x18\x03 \x03(\x01R\x04\x64\x61ta2\xf3\n\n\x0fSetDailyService\x12\x80\x01\n\x10WriteDailyScalar\x12:.systemathics.apis.services.daily.v2.SetDailyScalarRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\"\x10/v2/daily_scalar\x12\x8e\x01\n\x16WriteDailyScalarStream\x12@.systemathics.apis.services.daily.v2.SetDailyScalarStreamRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\"\x10/v2/daily_scalar(\x01\x12\x80\x01\n\x10WriteDailyVector\x12:.systemathics.apis.services.daily.v2.SetDailyVectorRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\"\x10/v2/daily_vector\x12\x8e\x01\n\x16WriteDailyVectorStream\x12@.systemathics.apis.services.daily.v2.SetDailyVectorStreamRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\"\x10/v2/daily_vector(\x01\x12\x81\x01\n\x11UpdateDailyScalar\x12:.systemathics.apis.services.daily.v2.SetDailyScalarRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\x1a\x10/v2/daily_scalar\x12\x8f\x01\n\x17UpdateDailyScalarStream\x12@.systemathics.apis.services.daily.v2.SetDailyScalarStreamRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\x1a\x10/v2/daily_scalar(\x01\x12\x81\x01\n\x11UpdateDailyVector\x12:.systemathics.apis.services.daily.v2.SetDailyVectorRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\x1a\x10/v2/daily_vector\x12\x8f\x01\n\x17UpdateDailyVectorStream\x12@.systemathics.apis.services.daily.v2.SetDailyVectorStreamRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\x1a\x10/v2/daily_vector(\x01\x12\x84\x01\n\x11\x44\x65leteDailyScalar\x12=.systemathics.apis.services.daily.v2.DeleteDailyScalarRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12*\x10/v2/daily_scalar\x12\x84\x01\n\x11\x44\x65leteDailyVector\x12=.systemathics.apis.services.daily.v2.DeleteDailyVectorRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12*\x10/v2/daily_vectorB\xe9\x01\n\'com.systemathics.apis.services.daily.v2B\rSetDailyProtoP\x01\xa2\x02\x04SASD\xaa\x02#Systemathics.Apis.Services.Daily.V2\xca\x02#Systemathics\\Apis\\Services\\Daily\\V2\xe2\x02/Systemathics\\Apis\\Services\\Daily\\V2\\GPBMetadata\xea\x02\'Systemathics::Apis::Services::Daily::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily.v2.set_daily_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.systemathics.apis.services.daily.v2B\rSetDailyProtoP\001\242\002\004SASD\252\002#Systemathics.Apis.Services.Daily.V2\312\002#Systemathics\\Apis\\Services\\Daily\\V2\342\002/Systemathics\\Apis\\Services\\Daily\\V2\\GPBMetadata\352\002\'Systemathics::Apis::Services::Daily::V2'
  _globals['_SETDAILYSCALARREQUEST_DATAENTRY']._options = None
  _globals['_SETDAILYSCALARREQUEST_DATAENTRY']._serialized_options = b'8\001'
  _globals['_SETDAILYVECTORREQUEST_DATAENTRY']._options = None
  _globals['_SETDAILYVECTORREQUEST_DATAENTRY']._serialized_options = b'8\001'
  _globals['_SETDAILYSERVICE'].methods_by_name['WriteDailyScalar']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['WriteDailyScalar']._serialized_options = b'\202\323\344\223\002\022\"\020/v2/daily_scalar'
  _globals['_SETDAILYSERVICE'].methods_by_name['WriteDailyScalarStream']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['WriteDailyScalarStream']._serialized_options = b'\202\323\344\223\002\022\"\020/v2/daily_scalar'
  _globals['_SETDAILYSERVICE'].methods_by_name['WriteDailyVector']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['WriteDailyVector']._serialized_options = b'\202\323\344\223\002\022\"\020/v2/daily_vector'
  _globals['_SETDAILYSERVICE'].methods_by_name['WriteDailyVectorStream']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['WriteDailyVectorStream']._serialized_options = b'\202\323\344\223\002\022\"\020/v2/daily_vector'
  _globals['_SETDAILYSERVICE'].methods_by_name['UpdateDailyScalar']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['UpdateDailyScalar']._serialized_options = b'\202\323\344\223\002\022\032\020/v2/daily_scalar'
  _globals['_SETDAILYSERVICE'].methods_by_name['UpdateDailyScalarStream']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['UpdateDailyScalarStream']._serialized_options = b'\202\323\344\223\002\022\032\020/v2/daily_scalar'
  _globals['_SETDAILYSERVICE'].methods_by_name['UpdateDailyVector']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['UpdateDailyVector']._serialized_options = b'\202\323\344\223\002\022\032\020/v2/daily_vector'
  _globals['_SETDAILYSERVICE'].methods_by_name['UpdateDailyVectorStream']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['UpdateDailyVectorStream']._serialized_options = b'\202\323\344\223\002\022\032\020/v2/daily_vector'
  _globals['_SETDAILYSERVICE'].methods_by_name['DeleteDailyScalar']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['DeleteDailyScalar']._serialized_options = b'\202\323\344\223\002\022*\020/v2/daily_scalar'
  _globals['_SETDAILYSERVICE'].methods_by_name['DeleteDailyVector']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['DeleteDailyVector']._serialized_options = b'\202\323\344\223\002\022*\020/v2/daily_vector'
  _globals['_SETDAILYSCALARREQUEST']._serialized_start=409
  _globals['_SETDAILYSCALARREQUEST']._serialized_end=696
  _globals['_SETDAILYSCALARREQUEST_DATAENTRY']._serialized_start=641
  _globals['_SETDAILYSCALARREQUEST_DATAENTRY']._serialized_end=696
  _globals['_SETDAILYSCALARSTREAMREQUEST']._serialized_start=699
  _globals['_SETDAILYSCALARSTREAMREQUEST']._serialized_end=891
  _globals['_SETDAILYVECTORREQUEST']._serialized_start=894
  _globals['_SETDAILYVECTORREQUEST']._serialized_end=1199
  _globals['_SETDAILYVECTORREQUEST_DATAENTRY']._serialized_start=641
  _globals['_SETDAILYVECTORREQUEST_DATAENTRY']._serialized_end=696
  _globals['_SETDAILYVECTORSTREAMREQUEST']._serialized_start=1202
  _globals['_SETDAILYVECTORSTREAMREQUEST']._serialized_end=1394
  _globals['_DELETEDAILYSCALARREQUEST']._serialized_start=1397
  _globals['_DELETEDAILYSCALARREQUEST']._serialized_end=1566
  _globals['_DELETEDAILYVECTORREQUEST']._serialized_start=1569
  _globals['_DELETEDAILYVECTORREQUEST']._serialized_end=1765
  _globals['_SETDAILYINFO']._serialized_start=1767
  _globals['_SETDAILYINFO']._serialized_end=1883
  _globals['_SETDAILYSCALARDATA']._serialized_start=1885
  _globals['_SETDAILYSCALARDATA']._serialized_end=1964
  _globals['_VECTORKEY']._serialized_start=1966
  _globals['_VECTORKEY']._serialized_end=2034
  _globals['_SETDAILYVECTORDATA']._serialized_start=2036
  _globals['_SETDAILYVECTORDATA']._serialized_end=2133
  _globals['_SETDAILYSERVICE']._serialized_start=2136
  _globals['_SETDAILYSERVICE']._serialized_end=3531
# @@protoc_insertion_point(module_scope)
