# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/filter.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-systemathics/apis/type/shared/v1/filter.proto\x12 systemathics.apis.type.shared.v1\x1a\x16google/type/date.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/api/field_behavior.proto\"\x97\x01\n\nDateFilter\x12/\n\x05\x65xact\x18\x01 \x01(\x0b\x32\x11.google.type.DateB\x04\xe2\x41\x01\x01H\x00R\x05\x65xact\x12O\n\x05range\x18\x02 \x01(\x0b\x32\x31.systemathics.apis.type.shared.v1.DateFilterRangeB\x04\xe2\x41\x01\x01H\x00R\x05rangeB\x07\n\x05oneof\"\x93\x01\n\x0f\x44\x61teFilterRange\x12\x34\n\tless_than\x18\x01 \x01(\x0b\x32\x11.google.type.DateB\x04\xe2\x41\x01\x01R\x08lessThan\x12J\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x11.google.type.DateB\x04\xe2\x41\x01\x01R\x12greaterOrEqualThan\"\x88\x01\n\x0c\x44oubleFilter\x12\x1c\n\x05\x65xact\x18\x01 \x01(\x01\x42\x04\xe2\x41\x01\x01H\x00R\x05\x65xact\x12Q\n\x05range\x18\x02 \x01(\x0b\x32\x33.systemathics.apis.type.shared.v1.DoubleFilterRangeB\x04\xe2\x41\x01\x01H\x00R\x05rangeB\x07\n\x05oneof\"\xab\x01\n\x11\x44oubleFilterRange\x12?\n\tless_than\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x04\xe2\x41\x01\x01R\x08lessThan\x12U\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x04\xe2\x41\x01\x01R\x12greaterOrEqualThan\"\x82\x01\n\tIntFilter\x12\x1c\n\x05\x65xact\x18\x01 \x01(\x03\x42\x04\xe2\x41\x01\x01H\x00R\x05\x65xact\x12N\n\x05range\x18\x02 \x01(\x0b\x32\x30.systemathics.apis.type.shared.v1.IntFilterRangeB\x04\xe2\x41\x01\x01H\x00R\x05rangeB\x07\n\x05oneof\"\xa6\x01\n\x0eIntFilterRange\x12>\n\tless_than\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x04\xe2\x41\x01\x01R\x08lessThan\x12T\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x04\xe2\x41\x01\x01R\x12greaterOrEqualThanB\xd8\x01\n$com.systemathics.apis.type.shared.v1B\x0b\x46ilterProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V1\xca\x02 Systemathics\\Apis\\Type\\Shared\\V1\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.filter_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v1B\013FilterProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V1\312\002 Systemathics\\Apis\\Type\\Shared\\V1\342\002,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V1'
  _globals['_DATEFILTER'].fields_by_name['exact']._options = None
  _globals['_DATEFILTER'].fields_by_name['exact']._serialized_options = b'\342A\001\001'
  _globals['_DATEFILTER'].fields_by_name['range']._options = None
  _globals['_DATEFILTER'].fields_by_name['range']._serialized_options = b'\342A\001\001'
  _globals['_DATEFILTERRANGE'].fields_by_name['less_than']._options = None
  _globals['_DATEFILTERRANGE'].fields_by_name['less_than']._serialized_options = b'\342A\001\001'
  _globals['_DATEFILTERRANGE'].fields_by_name['greater_or_equal_than']._options = None
  _globals['_DATEFILTERRANGE'].fields_by_name['greater_or_equal_than']._serialized_options = b'\342A\001\001'
  _globals['_DOUBLEFILTER'].fields_by_name['exact']._options = None
  _globals['_DOUBLEFILTER'].fields_by_name['exact']._serialized_options = b'\342A\001\001'
  _globals['_DOUBLEFILTER'].fields_by_name['range']._options = None
  _globals['_DOUBLEFILTER'].fields_by_name['range']._serialized_options = b'\342A\001\001'
  _globals['_DOUBLEFILTERRANGE'].fields_by_name['less_than']._options = None
  _globals['_DOUBLEFILTERRANGE'].fields_by_name['less_than']._serialized_options = b'\342A\001\001'
  _globals['_DOUBLEFILTERRANGE'].fields_by_name['greater_or_equal_than']._options = None
  _globals['_DOUBLEFILTERRANGE'].fields_by_name['greater_or_equal_than']._serialized_options = b'\342A\001\001'
  _globals['_INTFILTER'].fields_by_name['exact']._options = None
  _globals['_INTFILTER'].fields_by_name['exact']._serialized_options = b'\342A\001\001'
  _globals['_INTFILTER'].fields_by_name['range']._options = None
  _globals['_INTFILTER'].fields_by_name['range']._serialized_options = b'\342A\001\001'
  _globals['_INTFILTERRANGE'].fields_by_name['less_than']._options = None
  _globals['_INTFILTERRANGE'].fields_by_name['less_than']._serialized_options = b'\342A\001\001'
  _globals['_INTFILTERRANGE'].fields_by_name['greater_or_equal_than']._options = None
  _globals['_INTFILTERRANGE'].fields_by_name['greater_or_equal_than']._serialized_options = b'\342A\001\001'
  _globals['_DATEFILTER']._serialized_start=173
  _globals['_DATEFILTER']._serialized_end=324
  _globals['_DATEFILTERRANGE']._serialized_start=327
  _globals['_DATEFILTERRANGE']._serialized_end=474
  _globals['_DOUBLEFILTER']._serialized_start=477
  _globals['_DOUBLEFILTER']._serialized_end=613
  _globals['_DOUBLEFILTERRANGE']._serialized_start=616
  _globals['_DOUBLEFILTERRANGE']._serialized_end=787
  _globals['_INTFILTER']._serialized_start=790
  _globals['_INTFILTER']._serialized_end=920
  _globals['_INTFILTERRANGE']._serialized_start=923
  _globals['_INTFILTERRANGE']._serialized_end=1089
# @@protoc_insertion_point(module_scope)
