# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.services.daily.v2 import get_daily_scalar_pb2 as systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2


class DailyScalarServiceStub(object):
    """Called to request daily prices data. 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DailyScalar = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.DailyScalarService/DailyScalar',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarResponse.FromString,
                )
        self.DailyScalarStream = channel.unary_stream(
                '/systemathics.apis.services.daily.v2.DailyScalarService/DailyScalarStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarStreamResponse.FromString,
                )
        self.DailyScalarFields = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.DailyScalarService/DailyScalarFields',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarFieldsResponse.FromString,
                )
        self.DailyScalarAssetProvider = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.DailyScalarService/DailyScalarAssetProvider',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarAssetProviderResponse.FromString,
                )


class DailyScalarServiceServicer(object):
    """Called to request daily prices data. 
    """

    def DailyScalar(self, request, context):
        """Gets daily historical data timeseries by identifier
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DailyScalarStream(self, request, context):
        """Gets daily historical data timeseries by identifier using streaming
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DailyScalarFields(self, request, context):
        """Gets daily historical data by date
        rpc DailyByDate(DailyDateRequest) returns (stream GetDailyByDateResponse)
        {
        option (google.api.http) = {
        		get: "/v2/daily_date/"
        };
        }

        Gets all available fields by asset and provider.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DailyScalarAssetProvider(self, request, context):
        """Gets all available provider by asset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DailyScalarServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DailyScalar': grpc.unary_unary_rpc_method_handler(
                    servicer.DailyScalar,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarResponse.SerializeToString,
            ),
            'DailyScalarStream': grpc.unary_stream_rpc_method_handler(
                    servicer.DailyScalarStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarStreamResponse.SerializeToString,
            ),
            'DailyScalarFields': grpc.unary_unary_rpc_method_handler(
                    servicer.DailyScalarFields,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarFieldsResponse.SerializeToString,
            ),
            'DailyScalarAssetProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.DailyScalarAssetProvider,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarAssetProviderResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.daily.v2.DailyScalarService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DailyScalarService(object):
    """Called to request daily prices data. 
    """

    @staticmethod
    def DailyScalar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.DailyScalarService/DailyScalar',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DailyScalarStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.daily.v2.DailyScalarService/DailyScalarStream',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DailyScalarFields(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.DailyScalarService/DailyScalarFields',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarFieldsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DailyScalarAssetProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.DailyScalarService/DailyScalarAssetProvider',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_get__daily__scalar__pb2.DailyScalarAssetProviderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
